# apileague
API League is a Hub for World Class APIs.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.4
- Package version: 1.6.4
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/ddsky/api-league-clients/tree/master/python/.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/ddsky/api-league-clients/tree/master/python/.git`)

Then import the package:
```python
import apileague
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import apileague
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import apileague
from apileague.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.apileague.com
# See configuration.py for a list of all supported configuration parameters.
configuration = apileague.Configuration(
    host = "https://api.apileague.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: apiKey
configuration.api_key['apiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['apiKey'] = 'Bearer'

# Configure API key authorization: headerApiKey
configuration.api_key['headerApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['headerApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with apileague.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = apileague.ArtApi(api_client)
    url = 'https://upload.wikimedia.org/wikipedia/commons/3/35/Basic_human_drawing.png' # str | The URL to the image.
    width = 200 # int | The maximum width of the image (default 400, max. 500). (optional)
    height = 200 # int | The maximum height of the image (default 400, max. 500). (optional)

    try:
        # Image to Ascii Art by URL API
        api_response = api_instance.image_to_ascii_art_by_urlapi(url, width=width, height=height)
        print("The response of ArtApi->image_to_ascii_art_by_urlapi:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ArtApi->image_to_ascii_art_by_urlapi: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.apileague.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArtApi* | [**image_to_ascii_art_by_urlapi**](docs/ArtApi.md#image_to_ascii_art_by_urlapi) | **GET** /convert-image-to-ascii-txt | Image to Ascii Art by URL API
*ArtApi* | [**random_poem_api**](docs/ArtApi.md#random_poem_api) | **GET** /retrieve-random-poem | Random Poem API
*BooksApi* | [**find_similar_books_api**](docs/BooksApi.md#find_similar_books_api) | **GET** /list-similar-books | Find Similar Books API
*BooksApi* | [**search_books_api**](docs/BooksApi.md#search_books_api) | **GET** /search-books | Search Books API
*FoodApi* | [**compute_nutrition_api**](docs/FoodApi.md#compute_nutrition_api) | **GET** /compute-nutrition | Compute Nutrition API
*FoodApi* | [**retrieve_recipe_information_api**](docs/FoodApi.md#retrieve_recipe_information_api) | **GET** /retrieve-recipe | Retrieve Recipe Information API
*FoodApi* | [**search_drinks_api**](docs/FoodApi.md#search_drinks_api) | **GET** /search-drinks | Search Drinks API
*FoodApi* | [**search_recipes_api**](docs/FoodApi.md#search_recipes_api) | **GET** /search-recipes | Search Recipes API
*FoodApi* | [**search_restaurants_api**](docs/FoodApi.md#search_restaurants_api) | **GET** /search-restaurants | Search Restaurants API
*HumorApi* | [**generate_nonsense_word_api**](docs/HumorApi.md#generate_nonsense_word_api) | **GET** /generate-nonsense-word | Generate Nonsense Word API
*HumorApi* | [**random_joke_api**](docs/HumorApi.md#random_joke_api) | **GET** /retrieve-random-joke | Random Joke API
*HumorApi* | [**random_meme_api**](docs/HumorApi.md#random_meme_api) | **GET** /retrieve-random-meme | Random Meme API
*HumorApi* | [**search_gifs_api**](docs/HumorApi.md#search_gifs_api) | **GET** /search-gifs | Search Gifs API
*HumorApi* | [**search_jokes_api**](docs/HumorApi.md#search_jokes_api) | **GET** /search-jokes | Search Jokes API
*HumorApi* | [**search_memes_api**](docs/HumorApi.md#search_memes_api) | **GET** /search-memes | Search Memes API
*KnowledgeApi* | [**random_quote_api**](docs/KnowledgeApi.md#random_quote_api) | **GET** /retrieve-random-quote | Random Quote API
*KnowledgeApi* | [**random_riddle_api**](docs/KnowledgeApi.md#random_riddle_api) | **GET** /retrieve-random-riddle | Random Riddle API
*KnowledgeApi* | [**random_trivia_api**](docs/KnowledgeApi.md#random_trivia_api) | **GET** /retrieve-random-trivia | Random Trivia API
*MathApi* | [**convert_units_api**](docs/MathApi.md#convert_units_api) | **GET** /convert-units | Convert Units API
*MediaApi* | [**detect_main_image_color_api**](docs/MediaApi.md#detect_main_image_color_api) | **GET** /detect-color | Detect Main Image Color API
*MediaApi* | [**rescale_image_api**](docs/MediaApi.md#rescale_image_api) | **GET** /rescale-image | Rescale Image API
*MediaApi* | [**search_icons_api**](docs/MediaApi.md#search_icons_api) | **GET** /search-icons | Search Icons API
*MediaApi* | [**search_royalty_free_images_api**](docs/MediaApi.md#search_royalty_free_images_api) | **GET** /search-images | Search Royalty Free Images API
*MediaApi* | [**vector_search_api**](docs/MediaApi.md#vector_search_api) | **GET** /search-vectors | Vector Search API
*NewsApi* | [**extract_news_api**](docs/NewsApi.md#extract_news_api) | **GET** /extract-news | Extract News API
*NewsApi* | [**search_news_api**](docs/NewsApi.md#search_news_api) | **GET** /search-news | Search News API
*NewsApi* | [**top_news_api**](docs/NewsApi.md#top_news_api) | **GET** /retrieve-top-news | Top News API
*StorageApi* | [**read_key_value_from_store_api**](docs/StorageApi.md#read_key_value_from_store_api) | **GET** /read-key-value | Read Key Value from Store API
*StorageApi* | [**store_key_value_getapi**](docs/StorageApi.md#store_key_value_getapi) | **GET** /store-key-value | Store Key Value (GET) API
*TextApi* | [**correct_spelling_api**](docs/TextApi.md#correct_spelling_api) | **GET** /correct-spelling | Correct Spelling API
*TextApi* | [**detect_gender_by_name_api**](docs/TextApi.md#detect_gender_by_name_api) | **GET** /detect-gender | Detect Gender by Name API
*TextApi* | [**detect_language_api**](docs/TextApi.md#detect_language_api) | **GET** /detect-language | Detect Language API
*TextApi* | [**detect_sentiment_api**](docs/TextApi.md#detect_sentiment_api) | **GET** /detect-sentiment | Detect Sentiment API
*TextApi* | [**extract_dates_api**](docs/TextApi.md#extract_dates_api) | **GET** /extract-dates | Extract Dates API
*TextApi* | [**extract_entities_api**](docs/TextApi.md#extract_entities_api) | **GET** /extract-entities | Extract Entities API
*TextApi* | [**list_word_synonyms_api**](docs/TextApi.md#list_word_synonyms_api) | **GET** /list-synonyms | List Word Synonyms API
*TextApi* | [**pluralize_word_api**](docs/TextApi.md#pluralize_word_api) | **GET** /pluralize-word | Pluralize Word API
*TextApi* | [**score_readability_api**](docs/TextApi.md#score_readability_api) | **GET** /score-readability | Score Readability API
*TextApi* | [**score_text_api**](docs/TextApi.md#score_text_api) | **GET** /score-text | Score Text API
*TextApi* | [**singularize_word_api**](docs/TextApi.md#singularize_word_api) | **GET** /singularize-word | Singularize Word API
*TextApi* | [**stem_text_api**](docs/TextApi.md#stem_text_api) | **GET** /stem-text | Stem Text API
*TextApi* | [**tag_part_of_speech_api**](docs/TextApi.md#tag_part_of_speech_api) | **GET** /tag-pos | Tag Part of Speech API
*WebApi* | [**extract_authors_api**](docs/WebApi.md#extract_authors_api) | **GET** /extract-authors | Extract Authors API
*WebApi* | [**extract_content_from_a_web_page_api**](docs/WebApi.md#extract_content_from_a_web_page_api) | **GET** /extract-content | Extract Content from a Web Page API
*WebApi* | [**extract_publish_date_api**](docs/WebApi.md#extract_publish_date_api) | **GET** /extract-publish-date | Extract Publish Date API
*WebApi* | [**retrieve_page_rank_api**](docs/WebApi.md#retrieve_page_rank_api) | **GET** /retrieve-page-rank | Retrieve Page Rank API
*WebApi* | [**search_web_api**](docs/WebApi.md#search_web_api) | **GET** /search-web | Search Web API
*WebApi* | [**verify_email_address_api**](docs/WebApi.md#verify_email_address_api) | **GET** /verify-email | Verify Email Address API


## Documentation For Models

 - [ComputeNutritionAPI200Response](docs/ComputeNutritionAPI200Response.md)
 - [ComputeNutritionAPI200ResponseIngredientBreakdownInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInner.md)
 - [ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner.md)
 - [ConvertUnitsAPI200Response](docs/ConvertUnitsAPI200Response.md)
 - [CorrectSpellingAPI200Response](docs/CorrectSpellingAPI200Response.md)
 - [DetectGenderByNameAPI200Response](docs/DetectGenderByNameAPI200Response.md)
 - [DetectLanguageAPI200ResponseInner](docs/DetectLanguageAPI200ResponseInner.md)
 - [DetectMainImageColorAPI200ResponseInner](docs/DetectMainImageColorAPI200ResponseInner.md)
 - [DetectSentimentAPI200Response](docs/DetectSentimentAPI200Response.md)
 - [DetectSentimentAPI200ResponseDocument](docs/DetectSentimentAPI200ResponseDocument.md)
 - [DetectSentimentAPI200ResponseSentencesInner](docs/DetectSentimentAPI200ResponseSentencesInner.md)
 - [ExtractAuthorsAPI200Response](docs/ExtractAuthorsAPI200Response.md)
 - [ExtractAuthorsAPI200ResponseAuthorsInner](docs/ExtractAuthorsAPI200ResponseAuthorsInner.md)
 - [ExtractContentFromAWebPageAPI200Response](docs/ExtractContentFromAWebPageAPI200Response.md)
 - [ExtractDatesAPI200Response](docs/ExtractDatesAPI200Response.md)
 - [ExtractDatesAPI200ResponseDatesInner](docs/ExtractDatesAPI200ResponseDatesInner.md)
 - [ExtractEntitiesAPI200Response](docs/ExtractEntitiesAPI200Response.md)
 - [ExtractEntitiesAPI200ResponseEntitiesInner](docs/ExtractEntitiesAPI200ResponseEntitiesInner.md)
 - [ExtractNewsAPI200Response](docs/ExtractNewsAPI200Response.md)
 - [ExtractNewsAPI200ResponseImagesInner](docs/ExtractNewsAPI200ResponseImagesInner.md)
 - [ExtractNewsAPI200ResponseVideosInner](docs/ExtractNewsAPI200ResponseVideosInner.md)
 - [ExtractPublishDateAPI200Response](docs/ExtractPublishDateAPI200Response.md)
 - [FindSimilarBooksAPI200Response](docs/FindSimilarBooksAPI200Response.md)
 - [GenerateNonsenseWordAPI200Response](docs/GenerateNonsenseWordAPI200Response.md)
 - [ListWordSynonymsAPI200Response](docs/ListWordSynonymsAPI200Response.md)
 - [PluralizeWordAPI200Response](docs/PluralizeWordAPI200Response.md)
 - [RandomMemeAPI200Response](docs/RandomMemeAPI200Response.md)
 - [RandomPoemAPI200Response](docs/RandomPoemAPI200Response.md)
 - [RandomQuoteAPI200Response](docs/RandomQuoteAPI200Response.md)
 - [RandomRiddleAPI200Response](docs/RandomRiddleAPI200Response.md)
 - [RandomTriviaAPI200Response](docs/RandomTriviaAPI200Response.md)
 - [ReadKeyValueFromStoreAPI200Response](docs/ReadKeyValueFromStoreAPI200Response.md)
 - [RetrievePageRankAPI200Response](docs/RetrievePageRankAPI200Response.md)
 - [RetrieveRecipeInformationAPI200Response](docs/RetrieveRecipeInformationAPI200Response.md)
 - [RetrieveRecipeInformationAPI200ResponseCredits](docs/RetrieveRecipeInformationAPI200ResponseCredits.md)
 - [RetrieveRecipeInformationAPI200ResponseDietaryProperties](docs/RetrieveRecipeInformationAPI200ResponseDietaryProperties.md)
 - [RetrieveRecipeInformationAPI200ResponseIngredientsInner](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures.md)
 - [RetrieveRecipeInformationAPI200ResponseInstructionsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner.md)
 - [RetrieveRecipeInformationAPI200ResponseNutrition](docs/RetrieveRecipeInformationAPI200ResponseNutrition.md)
 - [RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner](docs/RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner.md)
 - [RetrieveRecipeInformationAPI200ResponseScores](docs/RetrieveRecipeInformationAPI200ResponseScores.md)
 - [RetrieveRecipeInformationAPI200ResponseTaste](docs/RetrieveRecipeInformationAPI200ResponseTaste.md)
 - [RetrieveRecipeInformationAPI200ResponseTimes](docs/RetrieveRecipeInformationAPI200ResponseTimes.md)
 - [ScoreReadabilityAPI200Response](docs/ScoreReadabilityAPI200Response.md)
 - [ScoreTextAPI200Response](docs/ScoreTextAPI200Response.md)
 - [ScoreTextAPI200ResponseInterestingness](docs/ScoreTextAPI200ResponseInterestingness.md)
 - [ScoreTextAPI200ResponseInterestingnessSubscores](docs/ScoreTextAPI200ResponseInterestingnessSubscores.md)
 - [ScoreTextAPI200ResponseReadability](docs/ScoreTextAPI200ResponseReadability.md)
 - [ScoreTextAPI200ResponseReadabilityMainscores](docs/ScoreTextAPI200ResponseReadabilityMainscores.md)
 - [ScoreTextAPI200ResponseReadabilitySubscores](docs/ScoreTextAPI200ResponseReadabilitySubscores.md)
 - [ScoreTextAPI200ResponseSkimmability](docs/ScoreTextAPI200ResponseSkimmability.md)
 - [ScoreTextAPI200ResponseSkimmabilityMainscores](docs/ScoreTextAPI200ResponseSkimmabilityMainscores.md)
 - [ScoreTextAPI200ResponseSkimmabilitySubscores](docs/ScoreTextAPI200ResponseSkimmabilitySubscores.md)
 - [ScoreTextAPI200ResponseStyle](docs/ScoreTextAPI200ResponseStyle.md)
 - [ScoreTextAPI200ResponseStyleSubscores](docs/ScoreTextAPI200ResponseStyleSubscores.md)
 - [SearchBooksAPI200Response](docs/SearchBooksAPI200Response.md)
 - [SearchBooksAPI200ResponseBooksInnerInner](docs/SearchBooksAPI200ResponseBooksInnerInner.md)
 - [SearchDrinksAPI200Response](docs/SearchDrinksAPI200Response.md)
 - [SearchDrinksAPI200ResponseDrinksInner](docs/SearchDrinksAPI200ResponseDrinksInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerCredits](docs/SearchDrinksAPI200ResponseDrinksInnerCredits.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric.md)
 - [SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutrition](docs/SearchDrinksAPI200ResponseDrinksInnerNutrition.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner.md)
 - [SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing.md)
 - [SearchGifsAPI200Response](docs/SearchGifsAPI200Response.md)
 - [SearchGifsAPI200ResponseImagesInner](docs/SearchGifsAPI200ResponseImagesInner.md)
 - [SearchIconsAPI200Response](docs/SearchIconsAPI200Response.md)
 - [SearchJokesAPI200Response](docs/SearchJokesAPI200Response.md)
 - [SearchJokesAPI200ResponseJokesInner](docs/SearchJokesAPI200ResponseJokesInner.md)
 - [SearchMemesAPI200Response](docs/SearchMemesAPI200Response.md)
 - [SearchMemesAPI200ResponseMemesInner](docs/SearchMemesAPI200ResponseMemesInner.md)
 - [SearchNewsAPI200Response](docs/SearchNewsAPI200Response.md)
 - [SearchNewsAPI200ResponseNewsInner](docs/SearchNewsAPI200ResponseNewsInner.md)
 - [SearchRecipesAPI200Response](docs/SearchRecipesAPI200Response.md)
 - [SearchRecipesAPI200ResponseRecipesInner](docs/SearchRecipesAPI200ResponseRecipesInner.md)
 - [SearchRecipesAPI200ResponseRecipesInnerNutrition](docs/SearchRecipesAPI200ResponseRecipesInnerNutrition.md)
 - [SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner](docs/SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner.md)
 - [SearchRestaurantsAPI200Response](docs/SearchRestaurantsAPI200Response.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInner](docs/SearchRestaurantsAPI200ResponseRestaurantsInner.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerAddress](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerAddress.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours.md)
 - [SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [SearchRoyaltyFreeImagesAPI200Response](docs/SearchRoyaltyFreeImagesAPI200Response.md)
 - [SearchRoyaltyFreeImagesAPI200ResponseImagesInner](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInner.md)
 - [SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense.md)
 - [SearchWebAPI200Response](docs/SearchWebAPI200Response.md)
 - [SearchWebAPI200ResponseResultsInner](docs/SearchWebAPI200ResponseResultsInner.md)
 - [SingularizeWordAPI200Response](docs/SingularizeWordAPI200Response.md)
 - [StemTextAPI200Response](docs/StemTextAPI200Response.md)
 - [StoreKeyValueGETAPI200Response](docs/StoreKeyValueGETAPI200Response.md)
 - [TagPartOfSpeechAPI200Response](docs/TagPartOfSpeechAPI200Response.md)
 - [TopNewsAPI200Response](docs/TopNewsAPI200Response.md)
 - [TopNewsAPI200ResponseTopNewsInner](docs/TopNewsAPI200ResponseTopNewsInner.md)
 - [TopNewsAPI200ResponseTopNewsInnerNewsInner](docs/TopNewsAPI200ResponseTopNewsInnerNewsInner.md)
 - [VectorSearchAPI200Response](docs/VectorSearchAPI200Response.md)
 - [VectorSearchAPI200ResponseVectorsInner](docs/VectorSearchAPI200ResponseVectorsInner.md)
 - [VerifyEmailAddressAPI200Response](docs/VerifyEmailAddressAPI200Response.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="apiKey"></a>
### apiKey

- **Type**: API key
- **API key parameter name**: api-key
- **Location**: URL query string

<a id="headerApiKey"></a>
### headerApiKey

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author

mail@apileague.com


